Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4612)

Unified Diff: chrome/browser/instant/instant_controller.h

Issue 10915217: Hook up SetInstantPreviewHeight for ChromeOS. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Move hidden notification, too. Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/instant/instant_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/instant/instant_controller.h
diff --git a/chrome/browser/instant/instant_controller.h b/chrome/browser/instant/instant_controller.h
index d2510e49414c8cbba18a91452fad8fba4bea810c..6ba4ebf37677ed5e05d9d6fc05b176b4309c99de 100644
--- a/chrome/browser/instant/instant_controller.h
+++ b/chrome/browser/instant/instant_controller.h
@@ -156,6 +156,9 @@ class InstantController : public InstantLoaderDelegate {
InstantLoader* loader,
const std::vector<InstantSuggestion>& suggestions) OVERRIDE;
virtual void CommitInstantLoader(InstantLoader* loader) OVERRIDE;
+ virtual void SetInstantPreviewHeight(InstantLoader* loader,
+ int height,
+ InstantSizeUnits units) OVERRIDE;
virtual void InstantLoaderPreviewLoaded(InstantLoader* loader) OVERRIDE;
virtual void InstantSupportDetermined(InstantLoader* loader,
bool supports_instant) OVERRIDE;
@@ -193,8 +196,9 @@ class InstantController : public InstantLoaderDelegate {
// Destroys the |loader_| and its preview contents.
void DeleteLoader();
- // Counterpart to Hide(). Asks the |delegate_| to display the preview.
- void Show();
+ // Counterpart to Hide(). Asks the |delegate_| to display the preview with
+ // the given |height|.
+ void Show(int height, InstantSizeUnits units);
// Send the omnibox dropdown bounds to the page.
void SendBoundsToPage();
« no previous file with comments | « no previous file | chrome/browser/instant/instant_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698